Stan Math Library: stan/math/fwd/core/operator_less_than.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

operator_less_than.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_CORE_OPERATOR_LESS_THAN_HPP
2 #define STAN_MATH_FWD_CORE_OPERATOR_LESS_THAN_HPP
3
4 #include <stan/math/fwd/core/fvar.hpp>
5
6
7 namespace stan {
8
9 namespace math {
10
11 template <typename T>
12 inline bool operator<(const fvar<T>& x,
13 double y) {
14 return x.val_ < y;
15 }
16
17 template <typename T>
18 inline bool operator<(double x,
19 const fvar<T>& y) {
20 return x < y.val_;
21 }
22
23 template <typename T>
24 inline bool operator<(const fvar<T>& x,
25 const fvar<T>& y) {
26 return x.val_ < y.val_;
27 }
28 }
29 }
30 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
fvar.hpp
stan::math::operator<
bool operator<(const fvar< T > &x, double y)
Definition: operator_less_than.hpp:12
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.